# CollaGen Framework
Collaborative Generation Framework for Generative Model 

[![Python](https://img.shields.io/badge/python-3.10-blue?style=round-square&logo=Python&color=3776AB)](https://www.python.org/) [![PyTorch](https://img.shields.io/badge/pytorch-latest-orange?style=round-square&logo=PyTorch&color=EE4C2C)](https://pytorch.org/)

## System Environments

### Python Dependent Packages

| Packagename | Version |              Note              |
|:-----------:|:-------:|:------------------------------:|
|   loguru    |  0.7.2  |          == to latest          |
|   pyyaml    |  6.0.1  |          == to latest          |
|    wandb    | 0.16.4  |          == to latest          |
|    torch    |  2.2.1  |          == to latest          |
| torchvision | 0.17.1  |          == to latest          |
|  datasets   | 2.18.0  | == to latest, FLock simulation |
|    peft     |  0.9.0  |          == to latest, FLock simulation          |
|    flask    |  3.0.2  |          == to latest, FLock simulation          |
|     trl     | 0.7.11  |          == to latest, FLock simulation          |
|     bitsandbytes     | 0.43.0  |          == to latest, FLock simulation          |

## Acknowledgments

We thank the following repos providing helpful components/functions in our work.

- [FedML](https://github.com/FedML-AI/FedML)
- [FederatedGPT-Shepherd](https://github.com/JayZhang42/FederatedGPT-Shepherd)